@@ -4,16 +4,19 @@ import tkinter as tk
 from tkinter import ttk
 from tkinter import filedialog
 from tkinter import messagebox
+from tkinter.font import Font
+
 from os import path
 from pprint import pformat
 import webbrowser
-from textwrap import dedent
+
 from dlapp import create_from_csv_data
 from dlapp import create_from_json_data
 from dlapp import create_from_yaml_data
 from dlapp.collection import Tabular
-from dlapp import version
+
 from dlapp import edition
+from dlapp.config import Data
 
 import platform
 
@@ -40,6 +43,58 @@ def get_relative_center_location(parent, width, height):
     return x, y
 
 
+def create_msgbox(title=None, error=None, warning=None, info=None,
+                  question=None, okcancel=None, retrycancel=None,
+                  yesno=None, yesnocancel=None, **options):
+    """create tkinter.messagebox
+    Parameters
+    ----------
+    title (str): a title of messagebox.  Default is None.
+    error (str): an error message.  Default is None.
+    warning (str): a warning message. Default is None.
+    info (str): an information message.  Default is None.
+    question (str): a question message.  Default is None.
+    okcancel (str): an ok or cancel message.  Default is None.
+    retrycancel (str): a retry or cancel message.  Default is None.
+    yesno (str): a yes or no message.  Default is None.
+    yesnocancel (str): a yes, no, or cancel message.  Default is None.
+    options (dict): options for messagebox.
+
+    Returns
+    -------
+    any: a string or boolean result
+    """
+    if error:
+        # a return result is a "ok" string
+        result = messagebox.showerror(title=title, message=error, **options)
+    elif warning:
+        # a return result is a "ok" string
+        result = messagebox.showwarning(title=title, message=warning, **options)
+    elif info:
+        # a return result is a "ok" string
+        result = messagebox.showinfo(title=title, message=info, **options)
+    elif question:
+        # a return result is a "yes" or "no" string
+        result = messagebox.askquestion(title=title, message=question, **options)
+    elif okcancel:
+        # a return result is boolean
+        result = messagebox.askokcancel(title=title, message=okcancel, **options)
+    elif retrycancel:
+        # a return result is boolean
+        result = messagebox.askretrycancel(title=title, message=retrycancel, **options)
+    elif yesno:
+        # a return result is boolean
+        result = messagebox.askyesno(title=title, message=yesno, **options)
+    elif yesnocancel:
+        # a return result is boolean or None
+        result = messagebox.askyesnocancel(title=title, message=yesnocancel, **options)
+    else:
+        # a return result is a "ok" string
+        result = messagebox.showinfo(title=title, message=info, **options)
+
+    return result
+
+
 def set_modal_dialog(dialog):
     """set dialog to become a modal dialog
 
@@ -53,51 +108,6 @@ def set_modal_dialog(dialog):
     dialog.wait_window()
 
 
-class Data:
-    license_name = 'BSD 3-Clause License'
-    repo_url = 'https://github.com/Geeks-Trident-LLC/dlapp'
-    license_url = path.join(repo_url, 'blob/main/LICENSE')
-    # TODO: Need to update wiki page for documentation_url instead of README.md.
-    documentation_url = path.join(repo_url, 'blob/develop/README.md')
-    copyright_text = 'Copyright @ 2021-2040 Geeks Trident LLC.  All rights reserved.'
-
-    @classmethod
-    def get_license(cls):
-        license_ = """
-            BSD 3-Clause License
-
-            Copyright (c) 2021-2040, Geeks Trident LLC
-            All rights reserved.
-
-            Redistribution and use in source and binary forms, with or without
-            modification, are permitted provided that the following conditions are met:
-
-            1. Redistributions of source code must retain the above copyright notice, this
-               list of conditions and the following disclaimer.
-
-            2. Redistributions in binary form must reproduce the above copyright notice,
-               this list of conditions and the following disclaimer in the documentation
-               and/or other materials provided with the distribution.
-
-            3. Neither the name of the copyright holder nor the names of its
-               contributors may be used to endorse or promote products derived from
-               this software without specific prior written permission.
-
-            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-            AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-            DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
-            FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-            DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-            SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-            CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-            OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-            OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-        """
-        license_ = dedent(license_).strip()
-        return license_
-
-
 class Content:
     """Content class
 
@@ -153,32 +163,32 @@ class Content:
                            'in form of json, yaml, yml, or csv.')
                     message = fmt.format(extension)
 
-                title = 'File extension'
-                messagebox.showwarning(title=title, message=message)
+                title = 'File Extension'
+                create_msgbox(title=title, warning=message)
 
             with open(self.filename, newline='') as stream:
                 self.data = stream.read().strip()
 
                 if not self.data:
                     message = 'This {} file is empty.'.format(self.filename)
-                    title = 'File extension'
-                    messagebox.showwarning(title=title, message=message)
+                    title = 'File Extension'
+                    create_msgbox(title=title, warnig=message)
 
     def process_data(self):
         if not self.data:
             if self.case != 'file':
-                title = 'Empty data'
+                title = 'Empty Data'
                 message = 'data is empty.'
-                messagebox.showwarning(title=title, message=message)
+                create_msgbox(title=title, warning=message)
 
             return
 
         if not self.filetype:
             if self.case != 'file':
-                title = 'Unselecting file extension'
+                title = 'Unselecting File Extension'
                 message = ('Need to check filetype radio button '
                            'such as json, yaml, or csv.')
-                messagebox.showwarning(title=title, message=message)
+                create_msgbox(title=title, warning=message)
                 return
 
         if self.is_yaml:
@@ -186,25 +196,25 @@ class Content:
                 self.query_obj = create_from_yaml_data(self.data)
                 self.ready = True
             except Exception as ex:
-                title = 'Processing YAML data'
-                message = '{}: {}'.format(type(ex), ex)
-                messagebox.showerror(title=title, message=message)
+                title = 'Processing YAML Data'
+                error = '{}: {}'.format(type(ex), ex)
+                create_msgbox(title=title, error=error)
         elif self.is_json:
             try:
                 self.query_obj = create_from_json_data(self.data)
                 self.ready = True
             except Exception as ex:
                 title = 'Processing JSON data'
-                message = '{}: {}'.format(type(ex), ex)
-                messagebox.showerror(title=title, message=message)
+                error = '{}: {}'.format(type(ex), ex)
+                create_msgbox(title=title, error=error)
         elif self.is_csv:
             try:
                 self.query_obj = create_from_csv_data(self.data)
                 self.ready = True
             except Exception as ex:
-                title = 'Processing CSV data'
-                message = '{}: {}'.format(type(ex), ex)
-                messagebox.showerror(title=title, message=message)
+                title = 'Processing CSV Data'
+                error = '{}: {}'.format(type(ex), ex)
+                create_msgbox(title=title, error=error)
 
     def process(self):
         """Analyze `self.filename` or `self.data` and
@@ -226,7 +236,6 @@ class Application:
     build_menu() -> None
     run() -> None
     callback_file_open() -> None
-    callback_file_exit() -> None
     callback_help_documentation() -> None
     callback_help_view_licenses() -> None
     callback_help_about() -> None
@@ -235,6 +244,22 @@ class Application:
     browser = webbrowser
 
     def __init__(self):
+        # support platform: macOS, Linux, and Window
+        self.is_macos = platform.system() == 'Darwin'
+        self.is_linux = platform.system() == 'Linux'
+        self.is_window = platform.system() == 'Windows'
+
+        # standardize tkinter widget for macOS, Linux, and Window operating system
+        self.RadioButton = tk.Radiobutton if self.is_linux else ttk.Radiobutton
+        self.CheckBox = tk.Checkbutton if self.is_linux else ttk.Checkbutton
+        self.Label = ttk.Label
+        self.Frame = ttk.Frame
+        self.LabelFrame = ttk.LabelFrame
+        self.Button = ttk.Button
+        self.TextBox = ttk.Entry
+        self.TextArea = tk.Text
+        self.PanedWindow = ttk.PanedWindow
+
         self._base_title = 'DLApp {}'.format(edition)
         self.root = tk.Tk()
         self.root.geometry('800x600+100+100')
@@ -242,7 +267,7 @@ class Application:
         self.root.option_add('*tearOff', False)
         self.content = None
 
-        self.panedwindow = None
+        self.paned_window = None
         self.text_frame = None
         self.entry_frame = None
         self.result_frame = None
@@ -253,25 +278,12 @@ class Application:
         self.select_entry_var = tk.StringVar()
         self.result = None
 
-        self.textarea = None
+        self.input_textarea = None
         self.result_textarea = None
         self.csv_radio_btn = None
         self.json_radio_btn = None
         self.yaml_radio_btn = None
 
-        self.is_macos = platform.system() == 'Darwin'
-        self.is_linux = platform.system() == 'Linux'
-        self.is_window = platform.system() == 'Windows'
-
-        self.RadioButton = tk.Radiobutton if self.is_linux else ttk.Radiobutton
-        self.Label = ttk.Label
-        self.Frame = ttk.Frame
-        self.LabelFrame = ttk.LabelFrame
-        self.Button = ttk.Button
-        self.TextBox = ttk.Entry
-        self.TextArea = tk.Text
-        self.PanedWindow = ttk.PanedWindow
-
         self.set_title()
         self.build_menu()
         self.build_frame()
@@ -279,22 +291,73 @@ class Application:
         self.build_entry()
         self.build_result()
 
-    def set_title(self, node=None, title=''):
-        """Set a new title for tkinter component.
+    def set_title(self, widget=None, title=''):
+        """Set a new title for tkinter widget.
 
         Parameters
         ----------
-        node (tkinter): a tkinter component.
+        widget (tkinter): a tkinter widget.
         title (str): a title.  Default is empty.
         """
-        node = node or self.root
+        widget = widget or self.root
         btitle = self._base_title
         title = '{} - {}'.format(title, btitle) if title else btitle
-        node.title(title)
+        widget.title(title)
 
-    def callback_file_exit(self):
-        """Callback for Menu File > Exit."""
-        self.root.quit()
+    def create_custom_label(self, parent, text='', link='',
+                            increased_size=0, bold=False, underline=False,
+                            italic=False):
+        """create custom label
+
+        Parameters
+        ----------
+        parent (tkinter): a parent of widget.
+        text (str): a text of widget.
+        link (str): a label hyperlink.
+        increased_size (int): a increased size for font.
+        bold (bool): True will set bold font.
+        underline (bool): True will set to underline font.
+        italic (bool): True will set to italic font.
+
+        Returns
+        -------
+        tkinter.Label: a label widget.
+        """
+
+        def mouse_over(event):
+            if 'underline' not in event.widget.font:
+                event.widget.configure(
+                    font=event.widget.font + ['underline'],
+                    cursor='hand2'
+                )
+
+        def mouse_out(event):
+            event.widget.config(
+                font=event.widget.font,
+                cursor='arrow'
+            )
+
+        def mouse_press(event):
+            self.browser.open_new_tab(event.widget.link)
+
+        style = ttk.Style()
+        style.configure("Blue.TLabel", foreground="blue")
+        if link:
+            label = self.Label(parent, text=text, style='Blue.TLabel')
+            label.bind('<Enter>', mouse_over)
+            label.bind('<Leave>', mouse_out)
+            label.bind('<Button-1>', mouse_press)
+        else:
+            label = self.Label(parent, text=text)
+        font = Font(name='TkDefaultFont', exists=True, root=label)
+        font = [font.cget('family'), font.cget('size') + increased_size]
+        bold and font.append('bold')
+        underline and font.append('underline')
+        italic and font.append('italic')
+        label.configure(font=font)
+        label.font = font
+        label.link = link
+        return label
 
     def callback_file_open(self):
         """Callback for Menu File > Open."""
@@ -309,8 +372,8 @@ class Application:
             content = Content(filename=filename)
             if content.is_ready:
                 self.set_title(title=filename)
-                self.textarea.delete("1.0", "end")
-                self.textarea.insert(tk.INSERT, content.data)
+                self.input_textarea.delete("1.0", "end")
+                self.input_textarea.insert(tk.INSERT, content.data)
                 self.radio_btn_var.set(content.filetype)
 
     def callback_help_documentation(self):
@@ -323,20 +386,10 @@ class Application:
 
     def callback_help_about(self):
         """Callback for Menu Help > About"""
-        def mouse_over(event):      # noqa
-            url_lbl.config(font=url_lbl.default_font + ('underline',))
-            url_lbl.config(cursor='hand2')
-
-        def mouse_out(event):       # noqa
-            url_lbl.config(font=url_lbl.default_font)
-            url_lbl.config(cursor='arrow')
-
-        def mouse_press(event):     # noqa
-            self.browser.open_new_tab(url_lbl.link)
 
         about = tk.Toplevel(self.root)
-        self.set_title(node=about, title='About')
-        width, height = 440, 400
+        self.set_title(widget=about, title='About')
+        width, height = 460, 460
         x, y = get_relative_center_location(self.root, width, height)
         about.geometry('{}x{}+{}+{}'.format(width, height, x, y))
         about.resizable(False, False)
@@ -344,59 +397,80 @@ class Application:
         top_frame = self.Frame(about)
         top_frame.pack(fill=tk.BOTH, expand=True)
 
-        panedwindow = self.PanedWindow(top_frame, orient=tk.VERTICAL)
-        panedwindow.pack(fill=tk.BOTH, expand=True, padx=8, pady=12)
+        paned_window = self.PanedWindow(top_frame, orient=tk.VERTICAL)
+        paned_window.pack(fill=tk.BOTH, expand=True, padx=8, pady=12)
 
         # company
-        frame = self.Frame(panedwindow, width=420, height=20)
-        panedwindow.add(frame, weight=1)
+        frame = self.Frame(paned_window, width=450, height=20)
+        paned_window.add(frame, weight=4)
 
-        fmt = 'DLApp v{} ({} Edition)'
-        company_lbl = self.Label(frame, text=fmt.format(version, edition))
-        company_lbl.pack(side=tk.LEFT)
+        self.create_custom_label(
+            frame, text=Data.main_app_text,
+            increased_size=2, bold=True
+        ).grid(row=0, column=0, columnspan=2, sticky=tk.W)
 
         # URL
-        frame = self.Frame(panedwindow, width=420, height=20)
-        panedwindow.add(frame, weight=1)
+        cell_frame = self.Frame(frame, width=450, height=5)
+        cell_frame.grid(row=1, column=0, sticky=tk.W, columnspan=2)
 
         url = Data.repo_url
-        self.Label(frame, text='URL:').pack(side=tk.LEFT)
-        font_size = 12 if self.is_macos else 10
-        style = ttk.Style()
-        style.configure("Blue.TLabel", foreground="blue")
-        url_lbl = self.Label(frame, text=url, font=('sans-serif', font_size))
-        url_lbl.config(style='Blue.TLabel')
-        url_lbl.default_font = ('sans-serif', font_size)
-        url_lbl.pack(side=tk.LEFT)
-        url_lbl.link = url
+        self.Label(cell_frame, text='URL:').pack(side=tk.LEFT)
 
-        url_lbl.bind('<Enter>', mouse_over)
-        url_lbl.bind('<Leave>', mouse_out)
-        url_lbl.bind('<Button-1>', mouse_press)
+        self.create_custom_label(
+            cell_frame, text=url, link=url
+        ).pack(side=tk.LEFT)
+
+        # dependencies
+        self.create_custom_label(
+            frame, text='Pypi.com Dependencies:', bold=True
+        ).grid(row=2, column=0, sticky=tk.W)
+
+        # compare_versions package
+        self.create_custom_label(
+            frame, text=Data.compare_versions_text,
+            link=Data.compare_versions_link
+        ).grid(row=3, column=0, padx=(20, 0), sticky=tk.W)
+
+        # python-dateutil package
+        self.create_custom_label(
+            frame, text=Data.python_dateutil_text,
+            link=Data.python_dateutil_link
+        ).grid(row=4, column=0, padx=(20, 0), pady=(0, 10), sticky=tk.W)
+
+        # PyYAML package
+        self.create_custom_label(
+            frame, text=Data.pyyaml_text,
+            link=Data.pyyaml_link
+        ).grid(row=3, column=1, padx=(20, 0), sticky=tk.W)
 
         # license textbox
         lframe = self.LabelFrame(
-            panedwindow, height=300, width=420,
+            paned_window, height=200, width=450,
             text=Data.license_name
         )
-        panedwindow.add(lframe, weight=7)
+        paned_window.add(lframe, weight=7)
 
-        width = 55 if self.is_macos else 48
-        height = 19 if self.is_macos else 15 if self.is_linux else 16
+        width = 58 if self.is_macos else 51
+        height = 18 if self.is_macos else 14 if self.is_linux else 15
         txtbox = self.TextArea(lframe, width=width, height=height, wrap='word')
         txtbox.grid(row=0, column=0, padx=5, pady=5)
         scrollbar = ttk.Scrollbar(lframe, orient=tk.VERTICAL, command=txtbox.yview)
         scrollbar.grid(row=0, column=1, sticky='nsew')
         txtbox.config(yscrollcommand=scrollbar.set)
-        txtbox.insert(tk.INSERT, Data.get_license())
+        txtbox.insert(tk.INSERT, Data.license)
         txtbox.config(state=tk.DISABLED)
 
         # footer - copyright
-        frame = self.Frame(panedwindow, width=380, height=20)
-        panedwindow.add(frame, weight=1)
+        frame = self.Frame(paned_window, width=450, height=20)
+        paned_window.add(frame, weight=1)
 
-        footer = self.Label(frame, text=Data.copyright_text)
-        footer.pack(side=tk.LEFT)
+        self.Label(frame, text=Data.copyright_text).pack(side=tk.LEFT, pady=(10, 10))
+
+        self.create_custom_label(
+            frame, text=Data.company, link=Data.company_url
+        ).pack(side=tk.LEFT, pady=(10, 10))
+
+        self.Label(frame, text='.  All right reserved.').pack(side=tk.LEFT, pady=(10, 10))
 
         set_modal_dialog(about)
 
@@ -412,7 +486,7 @@ class Application:
 
         file.add_command(label='Open', command=lambda: self.callback_file_open())
         file.add_separator()
-        file.add_command(label='Quit', command=lambda: self.callback_file_exit())
+        file.add_command(label='Quit', command=lambda: self.root.quit())
 
         help_.add_command(label='Documentation',
                           command=lambda: self.callback_help_documentation())
@@ -423,45 +497,45 @@ class Application:
 
     def build_frame(self):
         """Build layout for DLApp."""
-        self.panedwindow = self.PanedWindow(self.root, orient=tk.VERTICAL)
-        self.panedwindow.pack(fill=tk.BOTH, expand=True)
+        self.paned_window = self.PanedWindow(self.root, orient=tk.VERTICAL)
+        self.paned_window.pack(fill=tk.BOTH, expand=True)
 
         self.text_frame = self.Frame(
-            self.panedwindow, width=600, height=400, relief=tk.RIDGE
+            self.paned_window, width=600, height=400, relief=tk.RIDGE
         )
         self.entry_frame = self.Frame(
-            self.panedwindow, width=600, height=100, relief=tk.RIDGE
+            self.paned_window, width=600, height=100, relief=tk.RIDGE
         )
         self.result_frame = self.Frame(
-            self.panedwindow, width=600, height=100, relief=tk.RIDGE
+            self.paned_window, width=600, height=100, relief=tk.RIDGE
         )
-        self.panedwindow.add(self.text_frame, weight=7)
-        self.panedwindow.add(self.entry_frame)
-        self.panedwindow.add(self.result_frame, weight=2)
+        self.paned_window.add(self.text_frame, weight=7)
+        self.paned_window.add(self.entry_frame)
+        self.paned_window.add(self.result_frame, weight=2)
 
     def build_textarea(self):
         """Build input text for DLApp."""
 
         self.text_frame.rowconfigure(0, weight=1)
         self.text_frame.columnconfigure(0, weight=1)
-        self.textarea = self.TextArea(self.text_frame, width=20, height=5, wrap='none')
-        self.textarea.grid(row=0, column=0, sticky='nswe')
+        self.input_textarea = self.TextArea(self.text_frame, width=20, height=5, wrap='none')
+        self.input_textarea.grid(row=0, column=0, sticky='nswe')
         vscrollbar = ttk.Scrollbar(
-            self.text_frame, orient=tk.VERTICAL, command=self.textarea.yview
+            self.text_frame, orient=tk.VERTICAL, command=self.input_textarea.yview
         )
         vscrollbar.grid(row=0, column=1, sticky='ns')
         hscrollbar = ttk.Scrollbar(
-            self.text_frame, orient=tk.HORIZONTAL, command=self.textarea.xview
+            self.text_frame, orient=tk.HORIZONTAL, command=self.input_textarea.xview
         )
         hscrollbar.grid(row=1, column=0, sticky='ew')
-        self.textarea.config(
+        self.input_textarea.config(
             yscrollcommand=vscrollbar.set, xscrollcommand=hscrollbar.set
         )
 
     def build_entry(self):
         """Build input entry for DLApp."""
         def callback_run_btn():
-            data = self.textarea.get('1.0', 'end').strip()
+            data = self.input_textarea.get('1.0', 'end').strip()
             filetype = self.radio_btn_var.get()
             lookup = self.lookup_entry_var.get()
             select = self.select_entry_var.get()
@@ -477,12 +551,12 @@ class Application:
                 self.result_textarea.insert(tk.INSERT, str(result))
 
             except Exception as ex:
-                title = 'Query problem'
-                message = '{}: {}'.format(type(ex).__name__, ex)
-                messagebox.showerror(title=title, message=message)
+                title = 'Query Problem'
+                error = '{}: {}'.format(type(ex).__name__, ex)
+                create_msgbox(title=title, error=error)
 
         def callback_tabular_btn():
-            data = self.textarea.get('1.0', 'end').strip()
+            data = self.input_textarea.get('1.0', 'end').strip()
             filetype = self.radio_btn_var.get()
             lookup = self.lookup_entry_var.get()
             select = self.select_entry_var.get()
@@ -507,12 +581,12 @@ class Application:
                 self.result_textarea.insert(tk.INSERT, str(text))
 
             except Exception as ex:
-                title = 'Query problem'
-                message = '{}: {}'.format(type(ex).__name__, ex)
-                messagebox.showerror(title=title, message=message)
+                title = 'Query Problem'
+                error = '{}: {}'.format(type(ex).__name__, ex)
+                create_msgbox(title=title, error=error)
 
         def callback_clear_text_btn():
-            self.textarea.delete("1.0", "end")
+            self.input_textarea.delete("1.0", "end")
             self.result_textarea.delete("1.0", "end")
             self.radio_btn_var.set(None)
             self.lookup_entry_var.set('')
@@ -525,23 +599,23 @@ class Application:
             if filetype == 'None':
                 title = 'Unselect CSV/JSON/YAML'
                 message = 'Please select CSV, JSON, or YAML.'
-                messagebox.showwarning(title=title, message=message)
+                create_msgbox(title=title, warning=message)
                 return
 
             try:
                 data = self.root.clipboard_get()
                 if data:
-                    self.textarea.delete("1.0", "end")
+                    self.input_textarea.delete("1.0", "end")
                     # filetype = self.radio_btn_var.get()
                     self.content = Content(data=data, filetype=filetype)
                     if self.content.is_ready:
                         self.set_title(title='<<PASTE - Clipboard>>')
-                        self.textarea.insert(tk.INSERT, data)
+                        self.input_textarea.insert(tk.INSERT, data)
                         self.radio_btn_var.set(self.content.filetype)
             except Exception as ex:     # noqa
                 title = 'Empty Clipboard',
                 message = 'CAN NOT paste because there is no data in pasteboard.'
-                messagebox.showwarning(title=title, message=message)
+                create_msgbox(title=title, warning=message)
 
         def callback_clear_lookup_entry():
             self.lookup_entry_var.set('')
